type PluginJson = {
    uid: string;
    name: string;
    description: string;
    version: string;
    authors?: string[];
    dependencies?: Record<string, string | "*">;
    compatibleVersions?: {
        min?: string | "*";
        max?: string | "*";
    } & ({
        min: string;
    } | {
        max: string;
    });
};
interface Plugin extends PluginJson {
    init(props: PluginProps): void;
    restart(): Promise<boolean | void> | boolean | void;
}
type PluginProps = {
    onMessage(props: Message): void;
    checker: typeof checker;
};

type MessageType = "critical" | "warning" | "info" | "debug";
type Message = {
    code?: number;
    type: MessageType;
    details?: Record<string, any> | string | number | boolean;
};

type RestartProps = {
    all?: boolean;
    uids?: string[];
};

declare function register(plugins: Plugin[]): void;

declare function verify(this: any, func: Function, name: string): boolean;

declare const checker: {
    verify: typeof verify;
};

declare function restart(props?: RestartProps): Promise<Record<string, boolean>>;

declare const mcore: {
    register: typeof register;
    restart: typeof restart;
};

export { mcore as default };
export type { Message, MessageType, Plugin, PluginJson, PluginProps, RestartProps };
